@@ -81,4 +81,4 @@ def test_acronyms():
     docs: List[Document] = annotator.annotate([doc], parameters)
     doc0 = docs[0]
     labels = list(set([a.labelName for a in doc0.annotations]))
-    assert labels == IsList("short", "long")
+    assert labels == IsList("short", "long", check_order=False)
